# qmlspectrum

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Python3](https://img.shields.io/badge/Language-Python3-red.svg)](https://www.python.org/download/releases/3.0/)

`qmlspectrum` is a small test-suite that uses [qml](https://www.qmlcode.org/) package for modeling spectra as continuous functions. In this repository, we also distribute specialized datasets and example scripts. 

## Installation

`qmlspectrum` can be installed using the Python package manager `pip3`

```
pip3 install qmlspectrum --user
```

## Dependencies

* `matplitlib`, `pandas`, `scipy`, `numpy`, `os`, `qml` all of which can be installed using the Python package manager `pip3`

## Citation

If you are using the program and the bigQM7ω dataset distributed here, please consider citing the following article and the QML code.        

[Ref-1] [_Quantum Machine Learning Transition Probabilities in Electronic Excitation Spectra across Chemical Space: The Resolution-vs.-Accuracy Dilemma_](https://arxiv.org/abs/2110.11798)                
Prakriti Kayastha, Sabyasachi Chakraborty, Raghunathan Ramakrishnan (2022)     

[Ref-2] [_AS Christensen, FA Faber, B Huang, LA Bratholm, A Tkatchenko, KR Muller, OA von Lilienfeld (2017) "QML: A Python Toolkit for Quantum Machine Learning, https://github.com/qmlcode/qml"_](https://github.com/qmlcode/qml)     
